@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Ryu::Node);
 
-our $VERSION = '1.002'; # VERSION
+our $VERSION = '1.003'; # VERSION
 
 =head1 NAME
 
@@ -305,7 +305,7 @@ sub decode {
 
 =head2 print
 
-Shortcut for C< ->each(sub { print }) >, except this will
+Shortcut for C<< ->each(sub { print }) >>, except this will
 also save the initial state of C< $\ > and use that for each
 call for consistency.
 
